@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2020 Dan Halbert for Adafruit Industries
 #
-# Copyright (c) 2020 Dan Halbert for Adafruit Industries LLC
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_ble_adafruit.adafruit_service`
 ================================================================================
@@ -50,27 +33,36 @@ from micropython import const
 
 from adafruit_ble.advertising import Advertisement, LazyObjectField
 from adafruit_ble.advertising.standard import ManufacturerData, ManufacturerDataField
+from adafruit_ble.advertising.adafruit import (
+    MANUFACTURING_DATA_ADT,
+    ADAFRUIT_COMPANY_ID,
+)
 from adafruit_ble.attributes import Attribute
 from adafruit_ble.characteristics import Characteristic
 from adafruit_ble.characteristics.int import Int32Characteristic, Uint32Characteristic
 from adafruit_ble.uuid import VendorUUID
 from adafruit_ble.services import Service
 
+try:
+    from typing import Optional
+    from _bleio import ScanEntry
+except ImportError:
+    pass
+
 
-_MANUFACTURING_DATA_ADT = const(0xFF)
-_ADAFRUIT_COMPANY_ID = const(0x0822)
 _PID_DATA_ID = const(0x0001)  # This is the same as the Radio data id, unfortunately.
 
 
-class AdafruitServerAdvertisement(Advertisement):
-    """Advertise the Adafruit company ID and the board USB PID.
-    """
+class AdafruitServerAdvertisement(
+    Advertisement
+):  # pylint: disable=too-few-public-methods
+    """Advertise the Adafruit company ID and the board USB PID."""
 
     match_prefixes = (
         struct.pack(
             "<BHBH",
-            _MANUFACTURING_DATA_ADT,
-            _ADAFRUIT_COMPANY_ID,
+            MANUFACTURING_DATA_ADT,
+            ADAFRUIT_COMPANY_ID,
             struct.calcsize("<HH"),
             _PID_DATA_ID,
         ),
@@ -78,15 +70,19 @@ class AdafruitServerAdvertisement(Advertisement):
     manufacturer_data = LazyObjectField(
         ManufacturerData,
         "manufacturer_data",
-        advertising_data_type=_MANUFACTURING_DATA_ADT,
-        company_id=_ADAFRUIT_COMPANY_ID,
+        advertising_data_type=MANUFACTURING_DATA_ADT,
+        company_id=ADAFRUIT_COMPANY_ID,
         key_encoding="<H",
     )
     pid = ManufacturerDataField(_PID_DATA_ID, "<H")
     """The USB PID (product id) for this board."""
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *, entry: Optional[ScanEntry] = None) -> None:
+        super().__init__(entry=entry)
+        # Return early if things have been set by an existing ScanEntry.
+        if entry:
+            return
+        # Creating an advertisement to send.
         self.connectable = True
         self.flags.general_discovery = True
         self.flags.le_only = True
@@ -96,14 +92,14 @@ class AdafruitService(Service):
     """Common superclass for all Adafruit board services."""
 
     @staticmethod
-    def adafruit_service_uuid(n):
+    def adafruit_service_uuid(n: int) -> VendorUUID:
         """Generate a VendorUUID which fills in a 16-bit value in the standard
         Adafruit Service UUID: ADAFnnnn-C332-42A8-93BD-25E905756CB8.
         """
         return VendorUUID("ADAF{:04x}-C332-42A8-93BD-25E905756CB8".format(n))
 
     @classmethod
-    def measurement_period_charac(cls, msecs=1000):
+    def measurement_period_charac(cls, msecs: int = 1000) -> Int32Characteristic:
         """Create a measurement_period Characteristic for use by a subclass."""
         return Int32Characteristic(
             uuid=cls.adafruit_service_uuid(0x0001),
@@ -112,7 +108,7 @@ class AdafruitService(Service):
         )
 
     @classmethod
-    def service_version_charac(cls, version=1):
+    def service_version_charac(cls, version: int = 1) -> Uint32Characteristic:
         """Create a service_version Characteristic for use by a subclass."""
         return Uint32Characteristic(
             uuid=cls.adafruit_service_uuid(0x0002),
