@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2020 Dan Halbert for Adafruit Industries
 #
-# Copyright (c) 2020 Dan Halbert for Adafruit Industries LLC
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_ble_adafruit.addressable_pixel_service`
 ================================================================================
@@ -41,7 +24,15 @@ from adafruit_ble.characteristics import Characteristic, ComplexCharacteristic
 from adafruit_ble.characteristics.int import Uint8Characteristic, Uint16Characteristic
 from adafruit_ble_adafruit.adafruit_service import AdafruitService
 
-PixelValues = namedtuple("PixelValues", ("start", "write_now", "data"),)
+try:
+    from typing import Optional
+except ImportError:
+    pass
+
+PixelValues = namedtuple(
+    "PixelValues",
+    ("start", "write_now", "data"),
+)
 """Namedtuple for pixel data and instructions.
 
 * start
@@ -71,14 +62,14 @@ class _PixelPacket(ComplexCharacteristic):
 
     uuid = AdafruitService.adafruit_service_uuid(0x903)
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(
             properties=Characteristic.WRITE,
             read_perm=Attribute.NO_ACCESS,
             max_length=self.MAX_LENGTH,
         )
 
-    def bind(self, service):
+    def bind(self, service: "AddressablePixelService") -> _bleio.PacketBuffer:
         """Binds the characteristic to the given Service."""
         bound_characteristic = super().bind(service)
         return _bleio.PacketBuffer(bound_characteristic, buffer_size=1)
@@ -112,12 +103,12 @@ class AddressablePixelService(AdafruitService):
     _pixel_packet = _PixelPacket()
     """Pixel-setting data."""
 
-    def __init__(self, service=None):
+    def __init__(self, service: Optional["AddressablePixelService"] = None) -> None:
         self._pixel_packet_buf = bytearray(_PixelPacket.MAX_LENGTH)
         super().__init__(service=service)
 
     @property
-    def values(self):
+    def values(self) -> Optional[PixelValues]:
         """Return a tuple (start, write_now, data) corresponding to the
         different parts of ``_pixel_packet``.
         """
@@ -128,5 +119,7 @@ class AddressablePixelService(AdafruitService):
             return None
 
         return PixelValues(
-            struct.unpack_from("<H", buf)[0], bool(buf[2] & 0x1), buf[3:num_read],
+            struct.unpack_from("<H", buf)[0],
+            bool(buf[2] & 0x1),
+            buf[3:num_read],
         )
